==> qmmp-dmo_1.5.0.orig.tar.bz2: qmmp-1.5.0/src/plugins/Visual/projectm/translations/projectm_plugin_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lt" sourcelanguage="lt">
<context>
    <name>ProjectMPlugin</name>
    <message>
        <location filename="../projectmplugin.cpp" line="41"/>
        <source>ProjectM</source>
        <translation>ProjectM</translation>
    </message>
</context>
<context>
    <name>ProjectMWidget</name>
    <message>
        <location filename="../projectmwidget.cpp" line="147"/>
        <source>&amp;Help</source>
        <translation>&amp;Pagalba</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="147"/>
        <source>F1</source>
        <translation>F1</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="148"/>
        <source>&amp;Show Song Title</source>
        <translation>&amp;Rodyti dainos pavadinimą</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="148"/>
        <source>F2</source>
        <translation>F2</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="149"/>
        <source>&amp;Show Preset Name</source>
        <translation>&amp;Rodyti vizualizacijos pavadinimą</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="149"/>
        <source>F3</source>
        <translation>F3</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="150"/>
        <source>&amp;Show Menu</source>
        <translation>&amp;Rodyti Meniu</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="150"/>
        <source>M</source>
        <translation>M</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="152"/>
        <source>&amp;Next Preset</source>
        <translation>&amp;Sekanti</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="152"/>
        <source>N</source>
        <translation>N</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="153"/>
        <source>&amp;Previous Preset</source>
        <translation>&amp;Atgal</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="153"/>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="154"/>
        <source>&amp;Random Preset</source>
        <translation>&amp;Atsitiktinė</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="154"/>
        <source>R</source>
        <translation>R</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="155"/>
        <source>&amp;Lock Preset</source>
        <translation>&amp;Užrakinti</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="155"/>
        <source>L</source>
        <translation>L</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="157"/>
        <source>&amp;Fullscreen</source>
        <translation>&amp;Visas ekranas</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="157"/>
        <source>F</source>
        <translation>F</translation>
    </message>
</context>
<context>
    <name>VisualProjectMFactory</name>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="29"/>
        <source>ProjectM</source>
        <translation>ProjectM</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="49"/>
        <source>About ProjectM Visual Plugin</source>
        <translation>Apie Qmmp vizualizacijos įskiepį</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="50"/>
        <source>Qmmp ProjectM Visual Plugin</source>
        <translation>Qmmp ProjectM vizualizacijos įskiepis</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="51"/>
        <source>This plugin adds projectM visualization</source>
        <translation>Šis įskiepis leidžia naudoti projectM vizualizacijas</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Sukūrė: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="53"/>
        <source>Based on libprojectM-qt library</source>
        <translation>Sukurta libprojectM-qt pagrindu</translation>
    </message>
</context>
</TS>

==> qmmp-dmo_1.6.4.orig.tar.bz2: qmmp-1.6.4/src/plugins/Visual/projectm/translations/projectm_plugin_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lt">
<context>
    <name>ProjectM4Widget</name>
    <message>
        <location filename="../projectm4widget.cpp" line="163"/>
        <source>&amp;Show Menu</source>
        <translation>&amp;Rodyti Meniu</translation>
    </message>
    <message>
        <location filename="../projectm4widget.cpp" line="163"/>
        <source>M</source>
        <translation>M</translation>
    </message>
    <message>
        <location filename="../projectm4widget.cpp" line="165"/>
        <source>&amp;Next Preset</source>
        <translation>&amp;Sekanti</translation>
    </message>
    <message>
        <location filename="../projectm4widget.cpp" line="165"/>
        <source>N</source>
        <translation>N</translation>
    </message>
    <message>
        <location filename="../projectm4widget.cpp" line="166"/>
        <source>&amp;Previous Preset</source>
        <translation>&amp;Atgal</translation>
    </message>
    <message>
        <location filename="../projectm4widget.cpp" line="166"/>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <location filename="../projectm4widget.cpp" line="167"/>
        <source>&amp;Shuffle</source>
        <translation>&amp;Sumaišyti</translation>
    </message>
    <message>
        <location filename="../projectm4widget.cpp" line="167"/>
        <source>R</source>
        <translation>R</translation>
    </message>
    <message>
        <location filename="../projectm4widget.cpp" line="168"/>
        <source>&amp;Lock Preset</source>
        <translation>&amp;Užrakinti</translation>
    </message>
    <message>
        <location filename="../projectm4widget.cpp" line="168"/>
        <source>L</source>
        <translation>L</translation>
    </message>
    <message>
        <location filename="../projectm4widget.cpp" line="170"/>
        <source>&amp;Fullscreen</source>
        <translation>&amp;Visas ekranas</translation>
    </message>
    <message>
        <location filename="../projectm4widget.cpp" line="170"/>
        <source>F</source>
        <translation>F</translation>
    </message>
</context>
<context>
    <name>ProjectMPlugin</name>
    <message>
        <location filename="../projectmplugin.cpp" line="41"/>
        <source>ProjectM</source>
        <translation>ProjectM</translation>
    </message>
</context>
<context>
    <name>ProjectMWidget</name>
    <message>
        <location filename="../projectmwidget.cpp" line="143"/>
        <source>&amp;Help</source>
        <translation>&amp;Pagalba</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="143"/>
        <source>F1</source>
        <translation>F1</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="144"/>
        <source>&amp;Show Song Title</source>
        <translation>&amp;Rodyti dainos pavadinimą</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="144"/>
        <source>F2</source>
        <translation>F2</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="145"/>
        <source>&amp;Show Preset Name</source>
        <translation>&amp;Rodyti vizualizacijos pavadinimą</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="145"/>
        <source>F3</source>
        <translation>F3</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="146"/>
        <source>&amp;Show Menu</source>
        <translation>&amp;Rodyti Meniu</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="146"/>
        <source>M</source>
        <translation>M</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="148"/>
        <source>&amp;Next Preset</source>
        <translation>&amp;Sekanti</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="148"/>
        <source>N</source>
        <translation>N</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="149"/>
        <source>&amp;Previous Preset</source>
        <translation>&amp;Atgal</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="149"/>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="150"/>
        <source>&amp;Random Preset</source>
        <translation>&amp;Atsitiktinė</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="150"/>
        <source>R</source>
        <translation>R</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="151"/>
        <source>&amp;Lock Preset</source>
        <translation>&amp;Užrakinti</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="151"/>
        <source>L</source>
        <translation>L</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="153"/>
        <source>&amp;Fullscreen</source>
        <translation>&amp;Visas ekranas</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="153"/>
        <source>F</source>
        <translation>F</translation>
    </message>
</context>
<context>
    <name>VisualProjectMFactory</name>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="29"/>
        <source>ProjectM</source>
        <translation>ProjectM</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="49"/>
        <source>About ProjectM Visual Plugin</source>
        <translation>Apie Qmmp vizualizacijos įskiepį</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="50"/>
        <source>Qmmp ProjectM Visual Plugin</source>
        <translation>Qmmp ProjectM vizualizacijos įskiepis</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="51"/>
        <source>This plugin adds projectM visualization</source>
        <translation>Šis įskiepis leidžia naudoti projectM vizualizacijas</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Sukūrė: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="53"/>
        <source>Based on libprojectM-qt library</source>
        <translation>Sukurta libprojectM-qt pagrindu</translation>
    </message>
</context>
</TS>
